@@ -18,26 +18,15 @@
 #include <sepol/policydb/hashtab.h>
 #include <sepol/policydb/symtab.h>
 
+#include "debug.h"
+#include "private.h"
 #include "kernel_to_common.h"
 
 
-void sepol_log_err(const char *fmt, ...)
-{
-	va_list argptr;
-	va_start(argptr, fmt);
-	if (vfprintf(stderr, fmt, argptr) < 0) {
-		_exit(EXIT_FAILURE);
-	}
-	va_end(argptr);
-	if (fprintf(stderr, "\n") < 0) {
-		_exit(EXIT_FAILURE);
-	}
-}
-
 void sepol_indent(FILE *out, int indent)
 {
 	if (fprintf(out, "%*s", indent * 4, "") < 0) {
-		sepol_log_err("Failed to write to output");
+		ERR(NULL, "Failed to write to output");
 	}
 }
 
@@ -46,56 +35,24 @@ void sepol_printf(FILE *out, const char *fmt, ...)
 	va_list argptr;
 	va_start(argptr, fmt);
 	if (vfprintf(out, fmt, argptr) < 0) {
-		sepol_log_err("Failed to write to output");
+		ERR(NULL, "Failed to write to output");
 	}
 	va_end(argptr);
 }
 
-__attribute__ ((format(printf, 1, 0)))
-static char *create_str_helper(const char *fmt, int num, va_list vargs)
+char *create_str(const char *fmt, ...)
 {
-	va_list vargs2;
-	char *str = NULL;
-	char *s;
-	size_t len;
-	int i, rc;
-
-	va_copy(vargs2, vargs);
-
-	len = strlen(fmt) + 1; /* +1 for '\0' */
-
-	for (i=0; i<num; i++) {
-		s = va_arg(vargs, char *);
-		len += strlen(s) - 2; /* -2 for each %s in fmt */
-	}
-
-	str = malloc(len);
-	if (!str) {
-		sepol_log_err("Out of memory");
-		goto exit;
-	}
-
-	rc = vsnprintf(str, len, fmt, vargs2);
-	if (rc < 0 || rc >= (int)len) {
-		goto exit;
-	}
-
-	return str;
-
-exit:
-	free(str);
-	return NULL;
-}
-
-char *create_str(const char *fmt, int num, ...)
-{
-	char *str = NULL;
+	char *str;
 	va_list vargs;
+	int rc;
 
-	va_start(vargs, num);
-	str = create_str_helper(fmt, num, vargs);
+	va_start(vargs, fmt);
+	rc = vasprintf(&str, fmt, vargs);
 	va_end(vargs);
 
+	if (rc == -1)
+		return NULL;
+
 	return str;
 }
 
@@ -103,17 +60,21 @@ int strs_init(struct strs **strs, size_t size)
 {
 	struct strs *new;
 
+	if (size == 0) {
+		size = 1;
+	}
+
 	*strs = NULL;
 
 	new = malloc(sizeof(struct strs));
 	if (!new) {
-		sepol_log_err("Out of memory");
+		ERR(NULL, "Out of memory");
 		return -1;
 	}
 
-	new->list = calloc(sizeof(char *), size);
+	new->list = calloc(size, sizeof(char *));
 	if (!new->list) {
-		sepol_log_err("Out of memory");
+		ERR(NULL, "Out of memory");
 		free(new);
 		return -1;
 	}
@@ -156,11 +117,11 @@ int strs_add(struct strs *strs, char *s)
 {
 	if (strs->num + 1 > strs->size) {
 		char **new;
-		unsigned i = strs->size;
+		size_t i = strs->size;
 		strs->size *= 2;
-		new = realloc(strs->list, sizeof(char *)*strs->size);
+		new = reallocarray(strs->list, strs->size, sizeof(char *));
 		if (!new) {
-			sepol_log_err("Out of memory");
+			ERR(NULL, "Out of memory");
 			return -1;
 		}
 		strs->list = new;
@@ -173,20 +134,18 @@ int strs_add(struct strs *strs, char *s)
 	return 0;
 }
 
-int strs_create_and_add(struct strs *strs, const char *fmt, int num, ...)
+int strs_create_and_add(struct strs *strs, const char *fmt, ...)
 {
 	char *str;
 	va_list vargs;
 	int rc;
 
-	va_start(vargs, num);
-	str = create_str_helper(fmt, num, vargs);
+	va_start(vargs, fmt);
+	rc = vasprintf(&str, fmt, vargs);
 	va_end(vargs);
 
-	if (!str) {
-		rc = -1;
+	if (rc == -1)
 		goto exit;
-	}
 
 	rc = strs_add(strs, str);
 	if (rc != 0) {
@@ -209,17 +168,17 @@ char *strs_remove_last(struct strs *strs)
 	return strs->list[strs->num];
 }
 
-int strs_add_at_index(struct strs *strs, char *s, unsigned index)
+int strs_add_at_index(struct strs *strs, char *s, size_t index)
 {
 	if (index >= strs->size) {
 		char **new;
-		unsigned i = strs->size;
+		size_t i = strs->size;
 		while (index >= strs->size) {
 			strs->size *= 2;
 		}
-		new = realloc(strs->list, sizeof(char *)*strs->size);
+		new = reallocarray(strs->list, strs->size, sizeof(char *));
 		if (!new) {
-			sepol_log_err("Out of memory");
+			ERR(NULL, "Out of memory");
 			return -1;
 		}
 		strs->list = new;
@@ -234,7 +193,7 @@ int strs_add_at_index(struct strs *strs, char *s, unsigned index)
 	return 0;
 }
 
-char *strs_read_at_index(struct strs *strs, unsigned index)
+char *strs_read_at_index(struct strs *strs, size_t index)
 {
 	if (index >= strs->num) {
 		return NULL;
@@ -258,12 +217,12 @@ void strs_sort(struct strs *strs)
 	qsort(strs->list, strs->num, sizeof(char *), strs_cmp);
 }
 
-unsigned strs_num_items(struct strs *strs)
+unsigned strs_num_items(const struct strs *strs)
 {
 	return strs->num;
 }
 
-size_t strs_len_items(struct strs *strs)
+size_t strs_len_items(const struct strs *strs)
 {
 	unsigned i;
 	size_t len = 0;
@@ -276,7 +235,7 @@ size_t strs_len_items(struct strs *strs)
 	return len;
 }
 
-char *strs_to_str(struct strs *strs)
+char *strs_to_str(const struct strs *strs)
 {
 	char *str = NULL;
 	size_t len = 0;
@@ -292,7 +251,7 @@ char *strs_to_str(struct strs *strs)
 	len = strs_len_items(strs) + strs->num;
 	str = malloc(len);
 	if (!str) {
-		sepol_log_err("Out of memory");
+		ERR(NULL, "Out of memory");
 		goto exit;
 	}
 
@@ -318,7 +277,7 @@ exit:
 	return str;
 }
 
-void strs_write_each(struct strs *strs, FILE *out)
+void strs_write_each(const struct strs *strs, FILE *out)
 {
 	unsigned i;
 
@@ -330,7 +289,7 @@ void strs_write_each(struct strs *strs, FILE *out)
 	}
 }
 
-void strs_write_each_indented(struct strs *strs, FILE *out, int indent)
+void strs_write_each_indented(const struct strs *strs, FILE *out, int indent)
 {
 	unsigned i;
 
@@ -351,14 +310,15 @@ int hashtab_ordered_to_strs(char *key, void *data, void *args)
 	return strs_add_at_index(strs, key, datum->value-1);
 }
 
-int ebitmap_to_strs(struct ebitmap *map, struct strs *strs, char **val_to_name)
+int ebitmap_to_strs(const struct ebitmap *map, struct strs *strs, char **val_to_name)
 {
 	struct ebitmap_node *node;
 	uint32_t i;
 	int rc;
 
-	ebitmap_for_each_bit(map, node, i) {
-		if (!ebitmap_get_bit(map, i)) continue;
+	ebitmap_for_each_positive_bit(map, node, i) {
+		if (!val_to_name[i])
+			continue;
 
 		rc = strs_add(strs, val_to_name[i]);
 		if (rc != 0) {
@@ -369,7 +329,7 @@ int ebitmap_to_strs(struct ebitmap *map, struct strs *strs, char **val_to_name)
 	return 0;
 }
 
-char *ebitmap_to_str(struct ebitmap *map, char **val_to_name, int sort)
+char *ebitmap_to_str(const struct ebitmap *map, char **val_to_name, int sort)
 {
 	struct strs *strs;
 	char *str = NULL;
@@ -397,27 +357,27 @@ exit:
 	return str;
 }
 
-int stack_init(struct strs **stack)
+int strs_stack_init(struct strs **stack)
 {
 	return strs_init(stack, STACK_SIZE);
 }
 
-void stack_destroy(struct strs **stack)
+void strs_stack_destroy(struct strs **stack)
 {
 	return strs_destroy(stack);
 }
 
-int stack_push(struct strs *stack, char *s)
+int strs_stack_push(struct strs *stack, char *s)
 {
 	return strs_add(stack, s);
 }
 
-char *stack_pop(struct strs *stack)
+char *strs_stack_pop(struct strs *stack)
 {
 	return strs_remove_last(stack);
 }
 
-int stack_empty(struct strs *stack)
+int strs_stack_empty(const struct strs *stack)
 {
 	return strs_num_items(stack) == 0;
 }
@@ -469,11 +429,9 @@ static int portcon_data_cmp(const void *a, const void *b)
 	rc = compare_ranges((*aa)->u.port.low_port, (*aa)->u.port.high_port,
 			    (*bb)->u.port.low_port, (*bb)->u.port.high_port);
 	if (rc == 0) {
-		if ((*aa)->u.port.protocol == (*bb)->u.port.protocol) {
-			rc = 0;
-		} else if ((*aa)->u.port.protocol == IPPROTO_TCP) {
+		if ((*aa)->u.port.protocol < (*bb)->u.port.protocol) {
 			rc = -1;
-		} else {
+		} else if ((*aa)->u.port.protocol > (*bb)->u.port.protocol) {
 			rc = 1;
 		}
 	}
@@ -483,10 +441,40 @@ static int portcon_data_cmp(const void *a, const void *b)
 
 static int netif_data_cmp(const void *a, const void *b)
 {
-	struct ocontext *const *aa = a;
-	struct ocontext *const *bb = b;
+	/* keep in sync with cil_post.c:cil_post_netifcon_compare() */
+	const struct ocontext *const *aa = a;
+	const struct ocontext *const *bb = b;
+	const char *a_name = (*aa)->u.name;
+	const char *b_name = (*bb)->u.name;
+	size_t a_stem = strcspn(a_name, "*?");
+	size_t b_stem = strcspn(b_name, "*?");
+	size_t a_len = strlen(a_name);
+	size_t b_len = strlen(b_name);
+	int a_iswildcard = a_stem != a_len;
+	int b_iswildcard = b_stem != b_len;
+	int rc;
 
-	return strcmp((*aa)->u.name, (*bb)->u.name);
+	/* order non-wildcards first */
+	rc = spaceship_cmp(a_iswildcard, b_iswildcard);
+	if (rc)
+		return rc;
+
+	/* order non-wildcards alphabetically */
+	if (!a_iswildcard)
+		return strcmp(a_name, b_name);
+
+	/* order by decreasing stem length */
+	rc = spaceship_cmp(a_stem, b_stem);
+	if (rc)
+		return -rc;
+
+	/* order '?' (0x3f) before '*' (0x2A) */
+	rc = spaceship_cmp(a_name[a_stem], b_name[b_stem]);
+	if (rc)
+		return -rc;
+
+	/* order alphabetically */
+	return strcmp(a_name, b_name);
 }
 
 static int node_data_cmp(const void *a, const void *b)
@@ -545,7 +533,7 @@ static int ibendport_data_cmp(const void *a, const void *b)
 	if (rc)
 		return rc;
 
-	return (*aa)->u.ibendport.port - (*bb)->u.ibendport.port;
+	return spaceship_cmp((*aa)->u.ibendport.port, (*bb)->u.ibendport.port);
 }
 
 static int pirq_data_cmp(const void *a, const void *b)
@@ -617,9 +605,9 @@ static int sort_ocontext_data(struct ocontext **ocons, int (*cmp)(const void *,
 		return 0;
 	}
 
-	data = calloc(sizeof(*data), num);
+	data = calloc(num, sizeof(*data));
 	if (!data) {
-		sepol_log_err("Out of memory\n");
+		ERR(NULL, "Out of memory");
 		return -1;
 	}
 
@@ -710,7 +698,7 @@ int sort_ocontexts(struct policydb *pdb)
 
 exit:
 	if (rc != 0) {
-		sepol_log_err("Error sorting ocontexts\n");
+		ERR(NULL, "Error sorting ocontexts");
 	}
 
 	return rc;
